This function builds a shiny application in the specified directory
that gives the maximum credible level at an entered covariate point.
build.shiny.calc(
credsubs.level,
cov.space,
name = "calc",
dir = ".",
title = "Credible Subsets Calculator",
instructions = "Select a covariate point."
)An object of class credsubs.level.
A data frame whose rows are human-readable
covariate points corresponding to the entries
of credsubs.level$level.
A character string indicating the name of the application.
The directory in which to place the application.
A character string to be displayed as the application title.
A character string to be displayed as instructions. HTML allowed.
The calculator creates a subdirectory according to name in
the directory specified by dir, and places in it files
server.R, ui.R, and config.RData. This application
requires the shiny package to run, and can be executed by passing
the directory path to run.shiny.calc(). The produced application
directory may be moved from its original location.