Runs the specified calculator using the shiny package.
Calculators must be built using build.shiny.calc.
run.shiny.calc(
app.dir = system.file("shiny", "alzheimers", package = "credsubs")
)A character string pointing to the application directory.
The app.dir argument need not exactly match the value recommended
by build.shiny.calc(), as long as it points to the correct directory.
For example, "./calc/", "calc/", and "calc" are
all equivalent. If no value is supplied, an example is run.